PreprocessorError

Enum PreprocessorError 

pub enum PreprocessorError {
Show 25 variants Endif { endif_span: Span, }, NoEndif { cond_token: Token, cond_token_span: Span, }, Elsif { elsif_span: Span, }, Else { else_span: Span, }, EndKeywords { end_keywords_span: Span, }, NoEndKeywords { begin_keywords_span: Span, }, InvalidDefineParameter { other_token: Token, other_span: Span, }, InvalidDefineArgument { other_token: Token, other_span: Span, }, InvalidVersionSpecifier { invalid_version: Token, invalid_version_span: Span, }, IncompleteDirective { directive_span: Span, }, IncompleteDefine { other_token: Token, other_span: Span, }, UndefinedMacro { undefined_name: String, undefined_span: Span, }, DuplicateMacroParameter { define_name: String, param_name: String, dup_span: Span, prev_span: Span, }, NoDefaultAfterDefault { default_param: String, default_param_span: Span, non_default_param: String, non_default_param_span: Span, }, NoMacroArguments { macro_name: String, define_span: Span, use_span: Span, }, TooManyMacroArguments { macro_name: String, define_span: Span, use_span: Span, expected: usize, found: usize, }, MissingMacroArgument { define_span: Span, use_span: Span, param_name: String, }, InvalidIdentifierFormation { param_name: String, arg_span: Span, }, InvalidRelativeTimescales { timescale_span: Span, }, IncompleteMacroWithToken { error_token: Token, error_span: Span, }, Include { include_path: String, include_path_span: Span, read_err: String, }, IncludeDepth { include_span: Span, }, VerboseError { err: VerboseError, }, NotPreviouslyDefinedMacro { macro_name: String, macro_span: Span, }, RedefinedMacro { macro_name: String, redef_span: Span, prev_def_span: Span, },
}
A wrapper around scarf_parser::PreprocessorError

See its documentation for details on each variant

Variants



Endif

Fields

endif_span: Span

The Span of the `endif



NoEndif

Fields

cond_token: Token

The conditional token (either Token::DirIfdef, Token::DirIfndef, Token::DirElsif, or Token::DirElse) with no matching `endif

cond_token_span: Span

The Span of the conditional token



Elsif

Fields

elsif_span: Span

The Span of the `elsif



Else

Fields

else_span: Span

The Span of the `else



EndKeywords

Fields

end_keywords_span: Span

The Span of the `end_keywords



NoEndKeywords

Fields

begin_keywords_span: Span

The Span of the unterminated `begin_keywords



InvalidDefineParameter

Fields

other_token: Token

The Token found instead of the `define parameter

other_span: Span

The Span of the token found instead



InvalidDefineArgument

Fields

other_token: Token

The Token found instead of the valid `define argument

other_span: Span

The Span of the token found instead



InvalidVersionSpecifier

Fields

invalid_version: Token

The Token provided instead of a valid version specifier

If the token is a Token::StringLiteral, the string isn’t a version recognized by 1800-2023

invalid_version_span: Span

The Span of the invalid version specifier



IncompleteDirective

Fields

directive_span: Span

The Span of the incomplete preprocessor directive

This is usually the primary directive, but can be other more indicative tokens as well, such as an unmatched opening parenthesis



IncompleteDefine

Fields

other_token: Token

If known, the Token found instead of a valid function macro argument specification

In the case that the token wasn’t tracked, the opening Token::Paren is referenced instead

other_span: Span

The Span of the token found instead



UndefinedMacro

Fields

undefined_name: String

The name of the undefined macro

undefined_span: Span

The Span of the undefined macro



DuplicateMacroParameter

Fields

define_name: String

The name of the macro for which duplicate parameters were specified

param_name: String

The name of the parameter that was specified multiple times

dup_span: Span

The Span of the duplicate specification

prev_span: Span

The Span of the previous/original specification



NoDefaultAfterDefault

Fields

default_param: String

The name of the previously-specified default parameter

default_param_span: Span

The Span of the previously-specified default parameter

non_default_param: String

The name of the non-default parameter

non_default_param_span: Span

The Span of the non-default parameter



NoMacroArguments

Fields

macro_name: String

The name of the macro

define_span: Span

The Span of the macro definition (with arguments)

use_span: Span

The Span where the macro was used with no arguments



TooManyMacroArguments

Fields

macro_name: String

The name of the macro

define_span: Span

The Span of the macro definition

use_span: Span

The Span where the macro was used with too many arguments

expected: usize

How many arguments were expected

found: usize

How many arguments were found



MissingMacroArgument

Fields

define_span: Span

The Span of the macro definition

use_span: Span

The Span where the macro was used with a missing argument

param_name: String

The name of the missing parameter



InvalidIdentifierFormation

Fields

param_name: String

The name of the parameter used in a preprocessor identifier

arg_span: Span

The Span of the invalid argument



InvalidRelativeTimescales

Fields

timescale_span: Span

The Span of the `timescale directive



IncompleteMacroWithToken

Fields

error_token: Token

The error-causing Token (either Token::EParen, Token::EBracket, or Token::EBrace)

error_span: Span

The error-causing Span



Include

Fields

include_path: String

The path for the `include directive

include_path_span: Span

The Span of the include path

read_err: String

The std::io::Error raised when attempting to read the file



IncludeDepth

Fields

include_span: Span

The Span of the `include directive that exceeded the limit



VerboseError

Fields

err: VerboseError

The VerboseError for the preprocessor error



NotPreviouslyDefinedMacro

Fields

macro_name: String

The name that wasn’t previously defined

macro_span: Span

The Span where the not-previously-defined name was specified



RedefinedMacro

Fields

macro_name: String

The name of the macro being redefined

redef_span: Span

The Span of the redefinition

prev_def_span: Span

The Span where the macro was previously defined

Implementations