parse_from_preprocess

Function parse_from_preprocess 

pub fn parse_from_preprocess(tokens: Vec<SpannedToken>) -> ParserResult
Same as parse, but operates on the output of preprocess

Comparitively, this incurs overhead from copying data between Rust and Python’s ownership models. Only use if you need to modify the output of preprocess before parsing