preprocess_from_lex

Function preprocess_from_lex 

pub fn preprocess_from_lex(
    tokens: Vec<SpannedToken>,
    include_paths: Vec<PathBuf>,
    defines: Vec<Define>,
) -> PreprocessorResult
Same as preprocess, but operates on the output of lex

Comparitively, this incurs overhead from copying data between Rust and Python’s ownership models. Only use if you need to modify the output of lex before preprocessing