Span

Struct Span 

pub struct Span {
    pub file: String,
    pub bytes: Bytes,
    pub expanded_from: Option<Box<Span>>,
    pub included_from: Option<Box<Span>>,
}
A wrapper around scarf_syntax::Span, providing a location in the source code where a Node was found

Fields

file: String

The source file

bytes: Bytes

The byte-span within the source file

expanded_from: Option<Box<Span>>

The Span of the original token, if this is a text macro

included_from: Option<Box<Span>>

The Span of the `include directive that produced this one, if any

Implementations

Source

impl Span

pub fn text(&self) -> PyResult<String>