pub enum PreprocessorError {
Show 25 variants
Endif {
endif_span: Span,
},
NoEndif {
cond_token: Token,
cond_token_span: Span,
},
Elsif {
elsif_span: Span,
},
Else {
else_span: Span,
},
EndKeywords {
end_keywords_span: Span,
},
NoEndKeywords {
begin_keywords_span: Span,
},
InvalidDefineParameter {
other_token: Token,
other_span: Span,
},
InvalidDefineArgument {
other_token: Token,
other_span: Span,
},
InvalidVersionSpecifier {
invalid_version: Token,
invalid_version_span: Span,
},
IncompleteDirective {
directive_span: Span,
},
IncompleteDefine {
other_token: Token,
other_span: Span,
},
UndefinedMacro {
undefined_name: String,
undefined_span: Span,
},
DuplicateMacroParameter {
define_name: String,
param_name: String,
dup_span: Span,
prev_span: Span,
},
NoDefaultAfterDefault {
default_param: String,
default_param_span: Span,
non_default_param: String,
non_default_param_span: Span,
},
NoMacroArguments {
macro_name: String,
define_span: Span,
use_span: Span,
},
TooManyMacroArguments {
macro_name: String,
define_span: Span,
use_span: Span,
expected: usize,
found: usize,
},
MissingMacroArgument {
define_span: Span,
use_span: Span,
param_name: String,
},
InvalidIdentifierFormation {
param_name: String,
arg_span: Span,
},
InvalidRelativeTimescales {
timescale_span: Span,
},
IncompleteMacroWithToken {
error_token: Token,
error_span: Span,
},
Include {
include_path: String,
include_path_span: Span,
read_err: String,
},
IncludeDepth {
include_span: Span,
},
VerboseError {
err: VerboseError,
},
NotPreviouslyDefinedMacro {
macro_name: String,
macro_span: Span,
},
RedefinedMacro {
macro_name: String,
redef_span: Span,
prev_def_span: Span,
},
}Expand description
A wrapper around scarf_parser::PreprocessorError
See its documentation for details on each variant
Variants
Endif
NoEndif
Fields
cond_token: TokenThe conditional token (either Token::DirIfdef, Token::DirIfndef,
Token::DirElsif, or Token::DirElse) with no matching `endif
Elsif
Else
EndKeywords
NoEndKeywords
InvalidDefineParameter
Fields
InvalidDefineArgument
Fields
InvalidVersionSpecifier
Fields
invalid_version: TokenThe Token provided instead of a valid version specifier
If the token is a Token::StringLiteral, the string isn’t a version recognized
by 1800-2023
IncompleteDirective
Fields
IncompleteDefine
Fields
other_token: TokenIf known, the Token found instead of a valid function macro argument specification
In the case that the token wasn’t tracked, the opening Token::Paren is referenced
instead
UndefinedMacro
Fields
DuplicateMacroParameter
Fields
NoDefaultAfterDefault
Fields
NoMacroArguments
Fields
TooManyMacroArguments
Fields
MissingMacroArgument
Fields
InvalidIdentifierFormation
Fields
InvalidRelativeTimescales
IncompleteMacroWithToken
Fields
error_token: TokenThe error-causing Token (either Token::EParen,
Token::EBracket, or Token::EBrace)
Include
Fields
read_err: StringThe std::io::Error raised when attempting to read the file
IncludeDepth
VerboseError
Fields
err: VerboseErrorThe VerboseError for the preprocessor error
NotPreviouslyDefinedMacro
Fields
RedefinedMacro
Implementations